@@ -25,6 +25,7 @@
 #include <QPixmap>
 #include <QSvgRenderer>
 
+
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgametheme.h>
 
@@ -69,7 +70,7 @@ bool Renderer::loadTheme(const QString& themeName) {
 			return false;
 		
 		discardCache = true;
-		m_currentTheme = "default";
+        m_currentTheme = QStringLiteral("default");
 	}
 	
 	bool res = m_renderer->load(theme.graphics());
@@ -89,51 +90,51 @@ bool Renderer::loadTheme(const QString& themeName) {
 void Renderer::fillNameHashes() {
 	m_borderNames = QVector<QString>();
 	m_borderNames << "";
-	m_borderNames << "1";
-	m_borderNames << "2";
-	m_borderNames << "12";
-	m_borderNames << "3";
-	m_borderNames << "13";
-	m_borderNames << "23";
-	m_borderNames << "123";
-	m_borderNames << "4";
-	m_borderNames << "14";
-	m_borderNames << "24";
-	m_borderNames << "124";
-	m_borderNames << "34";
-	m_borderNames << "134";
-	m_borderNames << "234";
-	m_borderNames << "1234";
+    m_borderNames << QStringLiteral("1");
+    m_borderNames << QStringLiteral("2");
+    m_borderNames << QStringLiteral("12");
+    m_borderNames << QStringLiteral("3");
+    m_borderNames << QStringLiteral("13");
+    m_borderNames << QStringLiteral("23");
+    m_borderNames << QStringLiteral("123");
+    m_borderNames << QStringLiteral("4");
+    m_borderNames << QStringLiteral("14");
+    m_borderNames << QStringLiteral("24");
+    m_borderNames << QStringLiteral("124");
+    m_borderNames << QStringLiteral("34");
+    m_borderNames << QStringLiteral("134");
+    m_borderNames << QStringLiteral("234");
+    m_borderNames << QStringLiteral("1234");
 	m_borderTypes << QString();
-	m_borderTypes << "row";
-	m_borderTypes << "column";
-	m_borderTypes << "block";
-	m_borderTypes << "special";
-	m_borderTypes << "block";	// Use block-type borders for cages.
-	m_borderTypes << "special";
-	m_borderTypes << "special";
+    m_borderTypes << QStringLiteral("row");
+    m_borderTypes << QStringLiteral("column");
+    m_borderTypes << QStringLiteral("block");
+    m_borderTypes << QStringLiteral("special");
+    m_borderTypes << QStringLiteral("block");	// Use block-type borders for cages.
+    m_borderTypes << QStringLiteral("special");
+    m_borderTypes << QStringLiteral("special");
 	m_borderTypes << QString();
-	m_borderTypes << "row_h";
-	m_borderTypes << "column_h";
-	m_borderTypes << "block_h";
-	m_borderTypes << "special_h";
-	m_borderTypes << "block_h";	// Use block-type borders for cages.
-	m_borderTypes << "special_h";
-	m_borderTypes << "special_h";
-	m_specialNames << "cell";
-	m_specialNames << "cell_preset";
-	m_specialNames << "cell";
-	m_specialNames << "cell_mistake";
-	m_specialNames << "cursor";
-	m_specialNames << "valuelist_item";
-	m_specialNames << "valuelist_selector";
-	m_special3dNames << "cell3d";
-	m_special3dNames << "cell3d_preset";
-	m_special3dNames << "cell3d";
-	m_special3dNames << "cell3d_mistake";
-	m_special3dNames << "cursor";
-	m_special3dNames << "valuelist_item";
-	m_special3dNames << "valuelist_selector";
+    m_borderTypes << QStringLiteral("row_h");
+    m_borderTypes << QStringLiteral("column_h");
+    m_borderTypes << QStringLiteral("block_h");
+    m_borderTypes << QStringLiteral("special_h");
+    m_borderTypes << QStringLiteral("block_h");	// Use block-type borders for cages.
+    m_borderTypes << QStringLiteral("special_h");
+    m_borderTypes << QStringLiteral("special_h");
+    m_specialNames << QStringLiteral("cell");
+    m_specialNames << QStringLiteral("cell_preset");
+    m_specialNames << QStringLiteral("cell");
+    m_specialNames << QStringLiteral("cell_mistake");
+    m_specialNames << QStringLiteral("cursor");
+    m_specialNames << QStringLiteral("valuelist_item");
+    m_specialNames << QStringLiteral("valuelist_selector");
+    m_special3dNames << QStringLiteral("cell3d");
+    m_special3dNames << QStringLiteral("cell3d_preset");
+    m_special3dNames << QStringLiteral("cell3d");
+    m_special3dNames << QStringLiteral("cell3d_mistake");
+    m_special3dNames << QStringLiteral("cursor");
+    m_special3dNames << QStringLiteral("valuelist_item");
+    m_special3dNames << QStringLiteral("valuelist_selector");
 	// TODO get this hardcoded values from the SVG file
 // 	m_markerName << "markers9" << "markers9" //...
 }
@@ -142,7 +143,7 @@ QPixmap Renderer::renderBackground(const QSize& size) const {
 	if(!m_renderer->isValid() || size.isEmpty()) return QPixmap();
 
 	QPixmap pix;
-	QString cacheName = QString("background_%1x%2").arg(size.width()).arg(size.height());
+    QString cacheName = QStringLiteral("background_%1x%2").arg(size.width()).arg(size.height());
 	if(!m_cache->findPixmap(cacheName, &pix))
 	{
 		pix = QPixmap(size);
@@ -177,7 +178,7 @@ QPixmap Renderer::renderSpecial(SpecialType type, int size) const {
 	//only show the errors if the option has been set
 	if(!Settings::showErrors() && type == SpecialCellMistake ) type = SpecialCell;
 	
-	QString cacheName = QString("special_%1_%2").arg(m_specialNames[type]).arg(size);
+    QString cacheName = QStringLiteral("special_%1_%2").arg(m_specialNames[type]).arg(size);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
@@ -204,12 +205,12 @@ QPixmap Renderer::renderSymbol(int symbol, int size, int max, SymbolType type) c
 
 	QString set;
 	if(max <= 9) {
-		set = "symbol";
+        set = QStringLiteral("symbol");
 	} else {
-		set = "symbol25";
+        set = QStringLiteral("symbol25");
 	}
 
-	QString cacheName = QString("%1_%2_%3_%4").arg(set).arg(symbol).arg(size).arg(type);
+    QString cacheName = QStringLiteral("%1_%2_%3_%4").arg(set).arg(symbol).arg(size).arg(type);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
@@ -227,17 +228,17 @@ QPixmap Renderer::renderSymbol(int symbol, int size, int max, SymbolType type) c
 		
 		switch(type) {
 			case SymbolPreset:
-				if(m_renderer->elementExists(QString("%1_%2_preset").arg(set).arg(symbol))) {
-					m_renderer->render(&p, QString("%1_%2_preset").arg(set).arg(symbol), r);
+                if(m_renderer->elementExists(QStringLiteral("%1_%2_preset").arg(set).arg(symbol))) {
+                    m_renderer->render(&p, QStringLiteral("%1_%2_preset").arg(set).arg(symbol), r);
 				} else {
-					m_renderer->render(&p, QString("%1_%2").arg(set).arg(symbol), r);
+                    m_renderer->render(&p, QStringLiteral("%1_%2").arg(set).arg(symbol), r);
 				}
 				break;
 			case SymbolEdited:
-				if(m_renderer->elementExists(QString("%1_%2_edited").arg(set).arg(symbol))) {
-					m_renderer->render(&p, QString("%1_%2_edited").arg(set).arg(symbol), r);
+                if(m_renderer->elementExists(QStringLiteral("%1_%2_edited").arg(set).arg(symbol))) {
+                    m_renderer->render(&p, QStringLiteral("%1_%2_edited").arg(set).arg(symbol), r);
 				} else {
-					m_renderer->render(&p, QString("%1_%2").arg(set).arg(symbol), r);
+                    m_renderer->render(&p, QStringLiteral("%1_%2").arg(set).arg(symbol), r);
 				}
 				break;
 		}
@@ -277,9 +278,9 @@ QPixmap Renderer::renderMarker(int symbol, int range, int size) const {
 	
 	QString set;
 	if(range <= 9) {
-		set = "symbol";
+        set = QStringLiteral("symbol");
 	} else {
-		set = "symbol25";
+        set = QStringLiteral("symbol25");
 	}
 	
 	// TODO this is a hardcoded list of possible marker-groupings
@@ -292,8 +293,8 @@ QPixmap Renderer::renderMarker(int symbol, int range, int size) const {
 		range = 25;
 	}
 
-	QString groupName = QString("markers%1").arg(range);
-	QString cacheName = QString("%1_%2_%3").arg(groupName).arg(symbol).arg(size);
+    QString groupName = QStringLiteral("markers%1").arg(range);
+    QString cacheName = QStringLiteral("%1_%2_%3").arg(groupName).arg(symbol).arg(size);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
@@ -301,15 +302,15 @@ QPixmap Renderer::renderMarker(int symbol, int range, int size) const {
 		QPainter p(&pix);
 		
 		// NOTE fix for Qt's QSvgRenderer size reporting bug
-		QRectF r(m_renderer->boundsOnElement(QString("%1_%2").arg(groupName).arg(symbol)));
-		QRectF from(m_renderer->boundsOnElement(QString("cell_%1").arg(groupName)));
+        QRectF r(m_renderer->boundsOnElement(QStringLiteral("%1_%2").arg(groupName).arg(symbol)));
+        QRectF from(m_renderer->boundsOnElement(QStringLiteral("cell_%1").arg(groupName)));
 		from.adjust(+0.5,+0.5,-0.5,-0.5); // << this is the fix
 		QRectF to(QRectF(0,0,size,size));
 
 		r.setTopLeft(fromRectToRect(r.topLeft(), from, to));
 		r.setBottomRight(fromRectToRect(r.bottomRight(), from, to));
 
-		m_renderer->render(&p, QString("%1_%2").arg(set).arg(symbol), r);
+        m_renderer->render(&p, QStringLiteral("%1_%2").arg(set).arg(symbol), r);
 		p.end();
 		m_cache->insertPixmap(cacheName, pix);
 	}
@@ -349,7 +350,7 @@ QPixmap Renderer::renderCageLabelOn(QPixmap pixmap, const QString & cageLabel)
 	// TODO - Do font setup once during resize? Put 0+-x/ in themes?
 	int size = pixmap.width();
 	QPainter p(&pixmap);
-	p.setPen(QString("white"));	// Text is white on a dark rectangle.
+    p.setPen(QStringLiteral("white"));	// Text is white on a dark rectangle.
 	p.setBrush(Qt::SolidPattern);
 
 	// Cage label uses top 1/4 of pixmap and text is 1/6 height of pixmap.
@@ -362,7 +363,7 @@ QPixmap Renderer::renderCageLabelOn(QPixmap pixmap, const QString & cageLabel)
         int w = fm.boundingRect(cageLabel).width();	// Width of text.
 	int h = fm.height();		// Total height of font.
 	int a = fm.ascent();		// Height from baseline of font.
-        int m = fm.boundingRect(QChar('1')).width()/2;	// Left-right margin = 1/2 width of '1'.
+        int m = fm.boundingRect(QLatin1Char('1')).width()/2;	// Left-right margin = 1/2 width of '1'.
 
 	// Paint background rect: text must be visible in light and dark themes.
 	p.fillRect(size/6 - m, (size + 3)/4 - a, w + 2*m, h, Qt::darkGray);
@@ -376,7 +377,7 @@ QPixmap Renderer::renderCageLabelOn(QPixmap pixmap, const QString & cageLabel)
 QPixmap Renderer::renderBorder(int border, GroupTypes type, int size) const {
 	if(!m_renderer->isValid() || size == 0) return QPixmap();
 	
-	QString cacheName = QString("contour_%1_%2_%3").arg(m_borderTypes[type]).arg(m_borderNames[border]).arg(size);
+    QString cacheName = QStringLiteral("contour_%1_%2_%3").arg(m_borderTypes[type]).arg(m_borderNames[border]).arg(size);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
@@ -384,13 +385,13 @@ QPixmap Renderer::renderBorder(int border, GroupTypes type, int size) const {
 		QPainter p(&pix);
 		
 		// NOTE fix for Qt's QSvgRenderer size reporting bug
-		QRectF r(m_renderer->boundsOnElement(QString("%1_%2").arg(m_borderTypes[type]).arg(m_borderNames[border])));
+        QRectF r(m_renderer->boundsOnElement(QStringLiteral("%1_%2").arg(m_borderTypes[type]).arg(m_borderNames[border])));
 		QRectF from(r.adjusted(+0.5,+0.5,-0.5,-0.5));
 		QRectF to(QRectF(0,0,size,size));
 		r.setTopLeft(fromRectToRect(r.topLeft(), from, to));
 		r.setBottomRight(fromRectToRect(r.bottomRight(), from, to));
 		
-		m_renderer->render(&p, QString("%1_%2").arg(m_borderTypes[type]).arg(m_borderNames[border]), r);
+        m_renderer->render(&p, QStringLiteral("%1_%2").arg(m_borderTypes[type]).arg(m_borderNames[border]), r);
 		p.end();
 		m_cache->insertPixmap(cacheName, pix);
 	}
@@ -401,7 +402,7 @@ QPixmap Renderer::renderBorder(int border, GroupTypes type, int size) const {
 QPixmap Renderer::renderSpecial3D(SpecialType type, int size) const {
 	if(!m_renderer->isValid() || size == 0) return QPixmap();
 
-	QString cacheName = QString("special_%1_%2").arg(m_special3dNames[type]).arg(size);
+    QString cacheName = QStringLiteral("special_%1_%2").arg(m_special3dNames[type]).arg(size);
 	QPixmap pix;
 	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
